@@ -7,6 +7,7 @@ import (
 	"runtime/debug"
 
 	"github.com/alecthomas/kong"
+	"github.com/charmbracelet/huh"
 	"github.com/charmbracelet/lipgloss"
 	"github.com/muesli/termenv"
 
@@ -72,7 +73,7 @@ func main() {
 		},
 	)
 	if err := ctx.Run(); err != nil {
-		if errors.Is(err, exit.ErrAborted) {
+		if errors.Is(err, exit.ErrAborted) || errors.Is(err, huh.ErrUserAborted) {
 			os.Exit(exit.StatusAborted)
 		}
 		fmt.Println(err)
