@@ -4,11 +4,9 @@ import (
 	"fmt"
 	"regexp"
 
-	"github.com/alecthomas/kong"
 	"github.com/charmbracelet/bubbles/viewport"
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/charmbracelet/gum/internal/stdin"
-	"github.com/charmbracelet/gum/style"
 )
 
 // Run provides a shell script interface for the viewport bubble.
@@ -50,9 +48,3 @@ func (o Options) Run() error {
 	}
 	return nil
 }
-
-// BeforeReset hook. Used to unclutter style flags.
-func (o Options) BeforeReset(ctx *kong.Context) error {
-	style.HideFlags(ctx)
-	return nil
-}
