@@ -23,7 +23,7 @@ import (
 
 	"github.com/charmbracelet/gum/internal/exit"
 	"github.com/charmbracelet/gum/timeout"
-	"github.com/mattn/go-isatty"
+	"github.com/charmbracelet/x/term"
 
 	"github.com/charmbracelet/bubbles/spinner"
 	tea "github.com/charmbracelet/bubbletea"
@@ -46,9 +46,11 @@ type model struct {
 	hasTimeout bool
 }
 
-var bothbuf strings.Builder
-var outbuf strings.Builder
-var errbuf strings.Builder
+var (
+	bothbuf strings.Builder
+	outbuf  strings.Builder
+	errbuf  strings.Builder
+)
 
 type finishCommandMsg struct {
 	stdout string
@@ -65,7 +67,7 @@ func commandStart(command []string) tea.Cmd {
 		}
 		cmd := exec.Command(command[0], args...) //nolint:gosec
 
-		if isatty.IsTerminal(os.Stdout.Fd()) {
+		if term.IsTerminal(os.Stdout.Fd()) {
 			stdout := io.MultiWriter(&bothbuf, &errbuf)
 			stderr := io.MultiWriter(&bothbuf, &outbuf)
 
@@ -99,6 +101,7 @@ func (m model) Init() tea.Cmd {
 		timeout.Init(m.timeout, nil),
 	)
 }
+
 func (m model) View() string {
 	if m.quitting && m.showOutput {
 		return strings.TrimPrefix(errbuf.String()+"\n"+outbuf.String(), "\n")
